@@ -23,21 +23,28 @@ class Cloak(nn.Module):
         self.rhos.requires_grad = False
         self.locs.requires_grad = False
 
+        self.normal_distribution = Normal(self.loc, self.scale)
+
     def print_locs(self):
         print(self.locs)
 
     def print_rhos(self):
         print(self.rhos)
 
+    def to(self, *args, **kwargs):
+        self = super().to(*args, **kwargs)
+        self.normal_distribution = Normal(self.loc.to(*args, **kwargs), self.scale.to(*args, **kwargs))
+        return self
+
     def forward(self, x):
         std = (1.0 +torch.tanh(self.rhos))/2*(self.max_scale-self.min_scale) +self.min_scale
         mask = (std < self.threshold_value).float()
-        data = x + std * Normal(self.loc, self.scale).sample(self.given_shape)
+        data = x + std * self.normal_distribution.sample(self.given_shape)
 
         x = torch.clamp(
-                data * mask + torch.min(x) * (1 - mask) + self.locs,
-                torch.min(x),
-                torch.max(x)
+                data * mask + 0 * (1 - mask) + self.locs,
+                0,
+                1
             )
 
         return x
